==> haskell-ansi-terminal0.11-0.11.5-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal0.11.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ansi-terminal
version:              0.11.5
visibility:           public
id:                   ansi-terminal-0.11.5-6euBxRNb39LF08hahWvEms
key:                  ansi-terminal-0.11.5-6euBxRNb39LF08hahWvEms
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Simple ANSI terminal support, with Windows compatibility
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.

category:             User Interfaces
abi:                  45ac4fd69ab4898cc69ef3cd525d2064
exposed:              True
exposed-modules:
    System.Console.ANSI, System.Console.ANSI.Codes,
    System.Console.ANSI.Types from ansi-terminal-types-0.11.5-2e7b4SC9BqWLAluvgmY9KY:System.Console.ANSI.Types

hidden-modules:       System.Console.ANSI.Unix
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ansi-terminal-0.11.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ansi-terminal-0.11.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal0.11
hs-libraries:         HSansi-terminal-0.11.5-6euBxRNb39LF08hahWvEms
depends:
    ansi-terminal-types-0.11.5-2e7b4SC9BqWLAluvgmY9KY base-4.16.4.0
    colour-2.3.6-9XZ0UIDKtRjEgaDeW5KVhY

haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal0.11/html/ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal0.11/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-terminal0.11-0.11.5-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal0.11.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ansi-terminal
version:              0.11.5
visibility:           public
id:                   ansi-terminal-0.11.5-KhGO0vRX3OhLB2O8NCqLl5
key:                  ansi-terminal-0.11.5-KhGO0vRX3OhLB2O8NCqLl5
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Simple ANSI terminal support, with Windows compatibility
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.

category:             User Interfaces
abi:                  bee78f458a64cbf31120e5f49b3b3e07
exposed:              True
exposed-modules:
    System.Console.ANSI, System.Console.ANSI.Codes,
    System.Console.ANSI.Types from ansi-terminal-types-0.11.5-JM7pX53OxkWAZY8kBMqBma:System.Console.ANSI.Types

hidden-modules:       System.Console.ANSI.Unix
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ansi-terminal-0.11.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ansi-terminal-0.11.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal0.11
hs-libraries:         HSansi-terminal-0.11.5-KhGO0vRX3OhLB2O8NCqLl5
depends:
    ansi-terminal-types-0.11.5-JM7pX53OxkWAZY8kBMqBma base-4.16.4.0
    colour-2.3.6-AI2hzUqbPunFaDYRM0i4RP

haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal0.11/html/ansi-terminal.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal0.11/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
